Crate cleasby_vigfusson_dictionary

Crate cleasby_vigfusson_dictionary 

Structs

DictionaryEntry
Individual dictionary entry. Each entry contains word, and at least one definition for the word. Many words have multiple definitions, or additional info in definitions.

Functions

get_dictionary
Get full list of dictionary words. This version contains strong and italic HTML tags to match the layout of the printed book.
get_no_markup_dictionary
Get full list of dictionary words. This version does not contain additional HTML formatting or any tags.